@@ -74,6 +74,7 @@ STRUCTURE = Nav(
                 Nav("Félix « Midas »", cat="invite"),
                 Nav("Florian « Trotte »", cat="invite"),
                 Nav("Grégoire « Koraysh »", cat="invite"),
+                Nav("Jules « Askeladden »", cat="invite"),
                 Nav("Louis « Imperia86 »", cat="habitue"),
                 Nav("Martin « Spigushe »", cat="habitue"),
                 Nav("Nicolas « NicolasP »", cat="invite"),
@@ -176,6 +177,7 @@ STRUCTURE = Nav(
                 Nav("31. Raffine vs Soul of Windgrace", cat="match"),
                 Nav("32. Grenzo vs Shanna", cat="match"),
                 Nav("33. Juri vs Wilson", cat="match"),
+                Nav("34. Grist vs Raffine", cat="match"),
             ],
         ),
         Nav(
